@@ -31,6 +31,6 @@ class SynchronizeUsers(threading.Thread):
 				new = date.compare(increased, date.timestamp) in ["present", "past"]
 			if new:
 				last = date.timestamp
-				response = self.restapi.synchronize_users(silent=self.silent)
+				response = self.restapi.users.synchronize(silent=self.silent)
 				r3sponse.log(response, log_level=-1, save_errors=True)
 			time.sleep(self.sleep_interval*60)
\ No newline at end of file
